@@ -17,9 +17,11 @@ import inspect
 baseDir = os.path.dirname(os.path.abspath(__file__))
 if __name__ == '__main__':
   from imports import filter_extensions
+  from imports import global_extensions
 else:
   sys.path.insert(0, baseDir)
   from imports import filter_extensions
+  from imports import global_extensions
   sys.path.pop(0)
 
 if not os.path.exists(f'{baseDir}/version'):
@@ -212,6 +214,8 @@ def LoadCustomFilters():
   global baseJ2Env
   for f in inspect.getmembers(filter_extensions, inspect.isfunction):
     baseJ2Env.filters.update({f[0]: f[1]})
+  for f in inspect.getmembers(global_extensions, inspect.isfunction):
+    baseJ2Env.globals.update({f[0]: f[1]})
 
 ##########################################
 # Logging
@@ -332,15 +336,12 @@ You can modify jinja's environment settings via the rest of the command line opt
     Log(f"ArgParsing(): The parent directory for the custom log file '{args.log_destination}' either does not exist or is not a directory, please check it!", quitWithStatus=1)
 
   if type(args.dump_to_dir) == str:
-    args.dump_to_dir = args.dump_to_dir.strip('/')
-    if not os.path.isdir(os.path.dirname(args.dump_to_dir)):
+    args.dump_to_dir = os.path.abspath(args.dump_to_dir.strip('/'))
+    if not os.path.isdir(args.dump_to_dir):
       Log(f"ArgParsing(): The parent directory for dumping completed templates to '{args.dump_to_dir}' does not exist, please check your arguments!", quitWithStatus=1)
 
     if os.path.isfile(args.dump_to_dir):
       Log(f"ArgParsing(): The location provided for dumping completed templates to is a file and not a directory '{args.dump_to_dir}', please check your arguments!", quitWithStatus=1)
-      
-    if not os.path.exists(args.dump_to_dir):
-      os.mkdir(args.dump_to_dir)
 
   vs = 0
   if args.verbose:
